@@ -1,19 +1,19 @@
 package AFS::KTC_PRINCIPAL;
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)KTC_PRINCIPAL.pm,v 2.0 2002/07/02 06:13:13 nog Exp"
+# RCS-Id: "@(#)$Id: KTC_PRINCIPAL.pm 528 2004-01-06 18:36:03Z nog $"
 #
-# Copyright  2001-2002 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
+# Copyright  2001-2004 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 #------------------------------------------------------------------------------
 
-use AFS;
+use AFS ();
 
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(AFS);
-$VERSION = sprintf("%d.%02d", q/2.0/ =~ /(\d+)\.(\d+)/);
+$VERSION = do{my@r=q/Major Version 2.2 $Rev: 528 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
 
 sub ListTokens {
     my $class  = shift;
@@ -27,9 +27,6 @@ sub ParseLoginName {
     AFS::ka_ParseLoginName(@_);
 }
 
-{ # this is to please version 1 and to avoid warning about redefined subroutines
-no warnings;
-
 sub new {
     # this whole construct is to please the old version from Roland
     if ($_[0] =~ /AFS::KTC_PRINCIPAL/) { my $class  = shift; }
@@ -44,8 +41,6 @@ sub new {
     AFS::KTC_PRINCIPAL::_new('AFS::KTC_PRINCIPAL', @args);
 }
 
-}
-
 
 # struct ktc_principal {
 #     char name[MAXKTCNAMELEN];
